pitcharraytools.PitchArray
==========================

.. abjad-lineage:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray

.. autoclass:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cell_tokens_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cell_widths_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.cells
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.columns
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.depth
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.dimensions
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.has_voice_crossing
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.is_rectangular
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pitches
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pitches_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.rows
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.size
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.storage_format
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.voice_crossing_count
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.weight
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.append_column
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.append_row
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.apply_pitches_by_row
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.copy_subarray
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.has_spanning_cell_over_index
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pad_to_depth
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pad_to_width
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pop_column
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.pop_row
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.remove_row
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__add__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__contains__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__eq__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__ge__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__gt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__iadd__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__le__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__lt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__ne__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__repr__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArray.PitchArray.PitchArray.__str__
   :noindex:
